@@ -5,7 +5,7 @@
 # Joan Ntzougani, gravitalsun@hotmail.com
 
 package Dancer2::Plugin::WebService;
-our	$VERSION = '4.3.0';
+our	$VERSION = '4.3.1';
 use	strict;
 use	warnings;
 use Encode;
@@ -592,11 +592,10 @@ my $plg = shift;
 	}
 
 	if ($plg->error) {
-	$plg->__HASH_TO_STRING({error=> $plg->error});
-	$plg->dsl->halt( $plg->reply_text )
+	$plg->__HASH_TO_STRING({error=> $plg->error})
 	}
 
-$plg->reply_text
+$plg->dsl->halt( $plg->reply_text )
 }
 
 
@@ -772,7 +771,7 @@ Dancer2::Plugin::WebService - RESTful Web Services with login, persistent data,
 
 =head1 VERSION
 
-version 4.3.0
+version 4.3.1
 
 =head1 SYNOPSIS
 
